@@ -38,9 +38,9 @@ EOT
 git fetch upstream --tags
 git checkout -b "$target" "$release"
 
-# Update openshift's master and take all needed files from there.
-git fetch openshift master
-git checkout openshift/master $custom_files
+# Update openshift's main and take all needed files from there.
+git fetch openshift main
+git checkout openshift/main $custom_files
 git add $custom_files
 git commit -m "Add openshift specific files."
 
