@@ -22,7 +22,7 @@ import (
 
 	"knative.dev/client/pkg/kn/commands"
 	"knative.dev/client/pkg/kn/commands/flags"
-	"knative.dev/client/pkg/sources/v1alpha2"
+	v1 "knative.dev/client/pkg/sources/v1"
 	"knative.dev/client/pkg/util"
 )
 
@@ -32,11 +32,11 @@ func NewAPIServerUpdateCommand(p *commands.KnParams) *cobra.Command {
 	var sinkFlags flags.SinkFlags
 
 	cmd := &cobra.Command{
-		Use:   "update NAME --resource RESOURCE --service-account ACCOUNTNAME --sink SINK --mode MODE",
-		Short: "Update an ApiServer source.",
+		Use:   "update NAME",
+		Short: "Update an api-server source",
 		Example: `
   # Update an ApiServerSource 'k8sevents' with different service account and sink service
-  kn source apiserver update k8sevents --service-account newsa --sink svc:newsvc`,
+  kn source apiserver update k8sevents --service-account newsa --sink ksvc:newsvc`,
 
 		RunE: func(cmd *cobra.Command, args []string) (err error) {
 			if len(args) != 1 {
@@ -60,7 +60,7 @@ func NewAPIServerUpdateCommand(p *commands.KnParams) *cobra.Command {
 				return err
 			}
 
-			source, err := sourcesClient.GetAPIServerSource(name)
+			source, err := sourcesClient.GetAPIServerSource(cmd.Context(), name)
 			if err != nil {
 				return err
 			}
@@ -68,7 +68,7 @@ func NewAPIServerUpdateCommand(p *commands.KnParams) *cobra.Command {
 				return fmt.Errorf("can't update apiserver source %s because it has been marked for deletion", name)
 			}
 
-			b := v1alpha2.NewAPIServerSourceBuilderFromExisting(source)
+			b := v1.NewAPIServerSourceBuilderFromExisting(source)
 			if cmd.Flags().Changed("service-account") {
 				b.ServiceAccount(updateFlags.ServiceAccountName)
 			}
@@ -86,7 +86,7 @@ func NewAPIServerUpdateCommand(p *commands.KnParams) *cobra.Command {
 			}
 
 			if cmd.Flags().Changed("sink") {
-				objectRef, err := sinkFlags.ResolveSink(dynamicClient, namespace)
+				objectRef, err := sinkFlags.ResolveSink(cmd.Context(), dynamicClient, namespace)
 				if err != nil {
 					return err
 				}
@@ -102,7 +102,7 @@ func NewAPIServerUpdateCommand(p *commands.KnParams) *cobra.Command {
 				b.CloudEventOverrides(ceOverridesMap, ceOverridesToRemove)
 			}
 
-			err = sourcesClient.UpdateAPIServerSource(b.Build())
+			err = sourcesClient.UpdateAPIServerSource(cmd.Context(), b.Build())
 			if err == nil {
 				fmt.Fprintf(cmd.OutOrStdout(), "ApiServer source '%s' updated in namespace '%s'.\n", args[0], namespace)
 			}
