@@ -22,7 +22,7 @@ import (
 
 	"gotest.tools/v3/assert"
 
-	"knative.dev/client/pkg/messaging/v1beta1"
+	v1beta1 "knative.dev/client/pkg/messaging/v1"
 	"knative.dev/client/pkg/util"
 )
 
