@@ -26,7 +26,7 @@ import (
 	"knative.dev/client/pkg/kn/commands/flags"
 	hprinters "knative.dev/client/pkg/printers"
 
-	messagingv1beta1 "knative.dev/eventing/pkg/apis/messaging/v1beta1"
+	messagingv1 "knative.dev/eventing/pkg/apis/messaging/v1"
 )
 
 // ListHandlers handles printing human readable table for `kn subscription list` command's output
@@ -46,7 +46,7 @@ func ListHandlers(h hprinters.PrintHandler) {
 }
 
 // printSubscription populates a single row of Subscription list
-func printSubscription(subscription *messagingv1beta1.Subscription, options hprinters.PrintOptions) ([]metav1beta1.TableRow, error) {
+func printSubscription(subscription *messagingv1.Subscription, options hprinters.PrintOptions) ([]metav1beta1.TableRow, error) {
 	row := metav1beta1.TableRow{
 		Object: runtime.RawExtension{Object: subscription},
 	}
@@ -83,7 +83,7 @@ func printSubscription(subscription *messagingv1beta1.Subscription, options hpri
 }
 
 // printSubscriptionList populates the Subscription list table rows
-func printSubscriptionList(subscriptionList *messagingv1beta1.SubscriptionList, options hprinters.PrintOptions) ([]metav1beta1.TableRow, error) {
+func printSubscriptionList(subscriptionList *messagingv1.SubscriptionList, options hprinters.PrintOptions) ([]metav1beta1.TableRow, error) {
 	if options.AllNamespaces {
 		return printSubscriptionListWithNamespace(subscriptionList, options)
 	}
@@ -94,8 +94,9 @@ func printSubscriptionList(subscriptionList *messagingv1beta1.SubscriptionList,
 		return subscriptionList.Items[i].GetName() < subscriptionList.Items[j].GetName()
 	})
 
-	for _, item := range subscriptionList.Items {
-		row, err := printSubscription(&item, options)
+	for i := range subscriptionList.Items {
+		item := &subscriptionList.Items[i]
+		row, err := printSubscription(item, options)
 		if err != nil {
 			return nil, err
 		}
@@ -106,16 +107,17 @@ func printSubscriptionList(subscriptionList *messagingv1beta1.SubscriptionList,
 }
 
 // printSubscriptionListWithNamespace populates the knative service table rows with namespace column
-func printSubscriptionListWithNamespace(subscriptionList *messagingv1beta1.SubscriptionList, options hprinters.PrintOptions) ([]metav1beta1.TableRow, error) {
+func printSubscriptionListWithNamespace(subscriptionList *messagingv1.SubscriptionList, options hprinters.PrintOptions) ([]metav1beta1.TableRow, error) {
 	rows := make([]metav1beta1.TableRow, 0, len(subscriptionList.Items))
 
 	// temporary slice for sorting services in non-default namespace
 	others := make([]metav1beta1.TableRow, 0, len(rows))
 
-	for _, subscription := range subscriptionList.Items {
+	for i := range subscriptionList.Items {
+		subscription := &subscriptionList.Items[i]
 		// Fill in with services in `default` namespace at first
 		if subscription.Namespace == "default" {
-			r, err := printSubscription(&subscription, options)
+			r, err := printSubscription(subscription, options)
 			if err != nil {
 				return nil, err
 			}
@@ -123,7 +125,7 @@ func printSubscriptionListWithNamespace(subscriptionList *messagingv1beta1.Subsc
 			continue
 		}
 		// put other services in temporary slice
-		r, err := printSubscription(&subscription, options)
+		r, err := printSubscription(subscription, options)
 		if err != nil {
 			return nil, err
 		}
