@@ -15,6 +15,7 @@
 package v1
 
 import (
+	"context"
 	"reflect"
 	"testing"
 
@@ -34,7 +35,7 @@ import (
 func TestApplyServiceWithNoImage(t *testing.T) {
 	_, client := setup()
 	serviceFaulty := newService("faulty-service")
-	_, err := client.ApplyService(serviceFaulty)
+	_, err := client.ApplyService(context.Background(), serviceFaulty)
 	assert.Assert(t, err != nil)
 	assert.Assert(t, util.ContainsAll(err.Error(), "image name"))
 }
@@ -55,7 +56,7 @@ func TestApplyServiceCreate(t *testing.T) {
 			return true, serviceNew, nil
 		})
 
-	hasChanged, err := client.ApplyService(serviceNew)
+	hasChanged, err := client.ApplyService(context.Background(), serviceNew)
 	assert.NilError(t, err)
 	assert.Assert(t, hasChanged, "service has changed")
 }
@@ -79,7 +80,7 @@ func TestApplyServiceUpdate(t *testing.T) {
 			return true, serviceNew, nil
 		})
 
-	hasChanged, err := client.ApplyService(serviceNew)
+	hasChanged, err := client.ApplyService(context.Background(), serviceNew)
 	assert.NilError(t, err)
 	assert.Assert(t, hasChanged, "service has changed")
 }
