@@ -23,7 +23,7 @@ import (
 	"testing"
 	"time"
 
-	"gotest.tools/assert"
+	"gotest.tools/v3/assert"
 	"k8s.io/apimachinery/pkg/util/wait"
 
 	"knative.dev/client/lib/test"
